@@ -1,3 +1,5 @@
+#ifndef __divonne_korobovcoeff_h__
+#define __divonne_korobovcoeff_h__
 //Compilation note for R interface: move into a .h
 
 #define KOROBOV_MINDIM 2
@@ -881,3 +883,4 @@ static short coeff[][32] = {
    {2662,902,2371,1920,1097,1476,1008,1012,3556,468,3374,2560,591,1446,2,298,298,149,149,149,149,149,3135,3135,3135,3135,3135,2,2,2,2,2},
    {2861,1407,1848,245,2186,1209,164,2577,625,132,657,2333,2333,2213,2213,2213,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2}
 };
+#endif
